@@ -31,6 +31,7 @@ enum PIRMakeName{
   Acer_Make,
   ADB_Make,
   Admiral_Make,
+  Airtech_Make,
   Aiwa_Make,
   Alpine_Make,
   Anitech_Make,
@@ -98,6 +99,7 @@ enum PIRMakeName{
   Kenwood_Make,
   Keymat_Make,
   Konka_Make,
+  Lasko_Make,
   Lexuz_Make,
   LG_Make,
   Lifetec_Make,
@@ -135,6 +137,7 @@ enum PIRMakeName{
   Raite_Make,
   RCA_Make,
   Roku_Make,
+  RussellHobbs_Make,
   Saba_Make,
   Sagem_Make,
   Sagemcom_Make,
